<?php
session_start();
if (!isset($_SESSION['username'])) {
    header("Location: login_form.php");
    exit();
}

require('mysqli_connect.php');

$cart = $_SESSION['cart'] ?? [];

$products = [];
$total = 0;

if (!empty($cart)) {
    $placeholders = implode(',', array_fill(0, count($cart), '?'));
    $types = str_repeat('i', count($cart));

    $stmt = mysqli_prepare($dbc, "SELECT * FROM products WHERE id IN ($placeholders)");
    mysqli_stmt_bind_param($stmt, $types, ...$cart);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    $products = mysqli_fetch_all($result, MYSQLI_ASSOC);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Your Cart – SimpleShop</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
<div class="container">
    <h2>Your Shopping Cart</h2>
    <a href="search_products.php">Back to Search</a><br><br>

    <?php if (empty($products)): ?>
        <p>Your cart is empty.</p>
    <?php else: ?>
        <ul>
            <?php foreach ($products as $p): ?>
                <li>
                    <strong><?php echo $p['name']; ?></strong> – $<?php echo $p['price']; ?>
                    <?php $total += $p['price']; ?>
                </li>
            <?php endforeach; ?>
        </ul>
        <p><strong>Total:</strong> $<?php echo number_format($total, 2); ?></p>
        <a href="checkout.php"><button>Go to Checkout</button></a>
    <?php endif; ?>
</div>
</body>
</html>
